==> haskell-mtl-prelude-2.0.3.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mtl-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mtl-prelude
version:              2.0.3.1
visibility:           public
id:                   mtl-prelude-2.0.3.1-1kQPd3o3Zp3HRhOoRzwOrG
key:                  mtl-prelude-2.0.3.1-1kQPd3o3Zp3HRhOoRzwOrG
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/mtl-prelude 
synopsis:
    Reexports of most definitions from "mtl" and "transformers" 

description:
    This package only exports definitions from the \"mtl\" and \"transformers\"
    libraries.
    Unlike every module of \"mtl\" it does not reexport
    @Control.Monad@ and @Control.Monad.Fix@.

    In combination with the <http://hackage.haskell.org/package/base-prelude "base-prelude"> library,
    this should give you a quite rich prelude.

    The @2.*@ versions are restricted by
    the feature set of @mtl-2.2@ and @transformers-0.4@,
    however they provide support for newer versions of those libraries as well.

category:             Prelude
abi:                  6dac5b7709880f57962cadf11b987cba
exposed:              True
exposed-modules:      MTLPrelude
import-dirs:          /usr/lib/ghc-9.0.2/site-local/mtl-prelude-2.0.3.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mtl-prelude-2.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/mtl-prelude-2.0.3.1
hs-libraries:         HSmtl-prelude-2.0.3.1-1kQPd3o3Zp3HRhOoRzwOrG
depends:              base-4.15.1.0 mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-mtl-prelude/html/mtl-prelude.haddock
haddock-html:         /usr/share/doc/haskell-mtl-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mtl-prelude-2.0.3.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mtl-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mtl-prelude
version:              2.0.3.2
visibility:           public
id:                   mtl-prelude-2.0.3.2-3T2dpNTh08jLXPw8pkyyme
key:                  mtl-prelude-2.0.3.2-3T2dpNTh08jLXPw8pkyyme
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/mtl-prelude 
synopsis:
    Reexports of most definitions from "mtl" and "transformers" 

description:
    This package only exports definitions from the \"mtl\" and \"transformers\"
    libraries.
    Unlike every module of \"mtl\" it does not reexport
    @Control.Monad@ and @Control.Monad.Fix@.

    In combination with the <http://hackage.haskell.org/package/base-prelude "base-prelude"> library,
    this should give you a quite rich prelude.

    The @2.*@ versions are restricted by
    the feature set of @mtl-2.2@ and @transformers-0.4@,
    however they provide support for newer versions of those libraries as well.

category:             Prelude
abi:                  f85fb98687d8fbca2f52ae7074f8c659
exposed:              True
exposed-modules:      MTLPrelude
import-dirs:          /usr/lib/ghc-9.0.2/site-local/mtl-prelude-2.0.3.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mtl-prelude-2.0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mtl-prelude
hs-libraries:         HSmtl-prelude-2.0.3.2-3T2dpNTh08jLXPw8pkyyme
depends:              base-4.15.1.0 mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-mtl-prelude/html/mtl-prelude.haddock
haddock-html:         /usr/share/doc/haskell-mtl-prelude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
